# Contributing

To contribute there are a few simple rules to follow.

- Run `pre-commit` checks
- Make sure everything has 100% coverage and all tests pass
- No dependencies
- Open a PR first... This was the CI can verify your work.
